// src/billable-items-v1-billable-item-billable-items.universal.ts
import { transformError as sdkTransformError } from "@wix/sdk-runtime/transform-error";
import { queryBuilder } from "@wix/sdk-runtime/query-builder";
import {
  renameKeysFromSDKRequestToRESTRequest,
  renameKeysFromRESTResponseToSDKResponse
} from "@wix/sdk-runtime/rename-all-nested-keys";

// src/billable-items-v1-billable-item-billable-items.http.ts
import { toURLSearchParams } from "@wix/sdk-runtime/rest-modules";
import { transformSDKFloatToRESTFloat } from "@wix/sdk-runtime/transformations/float";
import { transformRESTFloatToSDKFloat } from "@wix/sdk-runtime/transformations/float";
import { transformSDKTimestampToRESTTimestamp } from "@wix/sdk-runtime/transformations/timestamp";
import { transformRESTTimestampToSDKTimestamp } from "@wix/sdk-runtime/transformations/timestamp";
import { transformSDKFieldMaskToRESTFieldMask } from "@wix/sdk-runtime/transformations/field-mask";
import { transformPaths } from "@wix/sdk-runtime/transformations/transform-paths";
import { resolveUrl } from "@wix/sdk-runtime/rest-modules";
function resolveWixBillableItemsV1BillableItemsUrl(opts) {
  const domainToMappings = {
    "manage._base_domain_": [
      {
        srcPath: "/_api/billable-items",
        destPath: ""
      }
    ],
    "www.wixapis.com": [
      {
        srcPath: "/billable-items/v1/billable-items",
        destPath: "/v1/billable-items"
      },
      {
        srcPath: "/billable-items/v1/bulk/billable-items",
        destPath: "/v1/bulk/billable-items"
      }
    ]
  };
  return resolveUrl(Object.assign(opts, { domainToMappings }));
}
var PACKAGE_NAME = "@wix/auto_sdk_get-paid_billable-items";
function createBillableItem(payload) {
  function __createBillableItem({ host }) {
    const serializedData = transformPaths(payload, [
      {
        transformFn: transformSDKTimestampToRESTTimestamp,
        paths: [
          { path: "billableItem.createdDate" },
          { path: "billableItem.updatedDate" }
        ]
      }
    ]);
    const metadata = {
      entityFqdn: "wix.billable_items.v1.billable_item",
      method: "POST",
      methodFqn: "wix.billable_items.v1.BillableItems.CreateBillableItem",
      packageName: PACKAGE_NAME,
      url: resolveWixBillableItemsV1BillableItemsUrl({
        protoPath: "/v1/billable-items",
        data: serializedData,
        host
      }),
      data: serializedData,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "billableItem.createdDate" },
            { path: "billableItem.updatedDate" }
          ]
        }
      ])
    };
    return metadata;
  }
  return __createBillableItem;
}
function getBillableItem(payload) {
  function __getBillableItem({ host }) {
    const metadata = {
      entityFqdn: "wix.billable_items.v1.billable_item",
      method: "GET",
      methodFqn: "wix.billable_items.v1.BillableItems.GetBillableItem",
      packageName: PACKAGE_NAME,
      url: resolveWixBillableItemsV1BillableItemsUrl({
        protoPath: "/v1/billable-items/{billableItemId}",
        data: payload,
        host
      }),
      params: toURLSearchParams(payload),
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "billableItem.createdDate" },
            { path: "billableItem.updatedDate" }
          ]
        }
      ])
    };
    return metadata;
  }
  return __getBillableItem;
}
function updateBillableItem(payload) {
  function __updateBillableItem({ host }) {
    const serializedData = transformPaths(payload, [
      {
        transformFn: transformSDKFieldMaskToRESTFieldMask,
        paths: [{ path: "fieldMask" }]
      },
      {
        transformFn: transformSDKTimestampToRESTTimestamp,
        paths: [
          { path: "billableItem.createdDate" },
          { path: "billableItem.updatedDate" }
        ]
      }
    ]);
    const metadata = {
      entityFqdn: "wix.billable_items.v1.billable_item",
      method: "PATCH",
      methodFqn: "wix.billable_items.v1.BillableItems.UpdateBillableItem",
      packageName: PACKAGE_NAME,
      url: resolveWixBillableItemsV1BillableItemsUrl({
        protoPath: "/v1/billable-items/{billableItem.id}",
        data: serializedData,
        host
      }),
      data: serializedData,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "billableItem.createdDate" },
            { path: "billableItem.updatedDate" }
          ]
        }
      ])
    };
    return metadata;
  }
  return __updateBillableItem;
}
function deleteBillableItem(payload) {
  function __deleteBillableItem({ host }) {
    const metadata = {
      entityFqdn: "wix.billable_items.v1.billable_item",
      method: "DELETE",
      methodFqn: "wix.billable_items.v1.BillableItems.DeleteBillableItem",
      packageName: PACKAGE_NAME,
      url: resolveWixBillableItemsV1BillableItemsUrl({
        protoPath: "/v1/billable-items/{billableItemId}",
        data: payload,
        host
      }),
      params: toURLSearchParams(payload)
    };
    return metadata;
  }
  return __deleteBillableItem;
}
function queryBillableItems(payload) {
  function __queryBillableItems({ host }) {
    const metadata = {
      entityFqdn: "wix.billable_items.v1.billable_item",
      method: "POST",
      methodFqn: "wix.billable_items.v1.BillableItems.QueryBillableItems",
      packageName: PACKAGE_NAME,
      url: resolveWixBillableItemsV1BillableItemsUrl({
        protoPath: "/v1/billable-items/query",
        data: payload,
        host
      }),
      data: payload,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "billableItems.createdDate" },
            { path: "billableItems.updatedDate" }
          ]
        }
      ]),
      fallback: [
        {
          method: "POST",
          url: resolveWixBillableItemsV1BillableItemsUrl({
            protoPath: "/v1/billable-items/query",
            data: payload,
            host
          }),
          data: payload
        }
      ]
    };
    return metadata;
  }
  return __queryBillableItems;
}
function bulkCreateBillableItems(payload) {
  function __bulkCreateBillableItems({ host }) {
    const serializedData = transformPaths(payload, [
      {
        transformFn: transformSDKTimestampToRESTTimestamp,
        paths: [
          { path: "billableItems.createdDate" },
          { path: "billableItems.updatedDate" }
        ]
      }
    ]);
    const metadata = {
      entityFqdn: "wix.billable_items.v1.billable_item",
      method: "POST",
      methodFqn: "wix.billable_items.v1.BillableItems.BulkCreateBillableItems",
      packageName: PACKAGE_NAME,
      url: resolveWixBillableItemsV1BillableItemsUrl({
        protoPath: "/v1/bulk/billable-items/create",
        data: serializedData,
        host
      }),
      data: serializedData,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "results.item.createdDate" },
            { path: "results.item.updatedDate" }
          ]
        }
      ])
    };
    return metadata;
  }
  return __bulkCreateBillableItems;
}
function bulkUpdateBillableItems(payload) {
  function __bulkUpdateBillableItems({ host }) {
    const serializedData = transformPaths(payload, [
      {
        transformFn: transformSDKFieldMaskToRESTFieldMask,
        paths: [{ path: "billableItems.fieldMask" }]
      },
      {
        transformFn: transformSDKTimestampToRESTTimestamp,
        paths: [
          { path: "billableItems.billableItem.createdDate" },
          { path: "billableItems.billableItem.updatedDate" }
        ]
      }
    ]);
    const metadata = {
      entityFqdn: "wix.billable_items.v1.billable_item",
      method: "POST",
      methodFqn: "wix.billable_items.v1.BillableItems.BulkUpdateBillableItems",
      packageName: PACKAGE_NAME,
      url: resolveWixBillableItemsV1BillableItemsUrl({
        protoPath: "/v1/bulk/billable-items/update",
        data: serializedData,
        host
      }),
      data: serializedData,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "results.item.createdDate" },
            { path: "results.item.updatedDate" }
          ]
        }
      ])
    };
    return metadata;
  }
  return __bulkUpdateBillableItems;
}
function bulkDeleteBillableItems(payload) {
  function __bulkDeleteBillableItems({ host }) {
    const metadata = {
      entityFqdn: "wix.billable_items.v1.billable_item",
      method: "POST",
      methodFqn: "wix.billable_items.v1.BillableItems.BulkDeleteBillableItems",
      packageName: PACKAGE_NAME,
      url: resolveWixBillableItemsV1BillableItemsUrl({
        protoPath: "/v1/bulk/billable-items/delete",
        data: payload,
        host
      }),
      data: payload
    };
    return metadata;
  }
  return __bulkDeleteBillableItems;
}
function bulkUpdateBillableItemTags(payload) {
  function __bulkUpdateBillableItemTags({ host }) {
    const metadata = {
      entityFqdn: "wix.billable_items.v1.billable_item",
      method: "POST",
      methodFqn: "wix.billable_items.v1.BillableItems.BulkUpdateBillableItemTags",
      packageName: PACKAGE_NAME,
      url: resolveWixBillableItemsV1BillableItemsUrl({
        protoPath: "/v1/bulk/billable-items/update-tags",
        data: payload,
        host
      }),
      data: payload
    };
    return metadata;
  }
  return __bulkUpdateBillableItemTags;
}
function bulkUpdateBillableItemTagsByFilter(payload) {
  function __bulkUpdateBillableItemTagsByFilter({ host }) {
    const metadata = {
      entityFqdn: "wix.billable_items.v1.billable_item",
      method: "POST",
      methodFqn: "wix.billable_items.v1.BillableItems.BulkUpdateBillableItemTagsByFilter",
      packageName: PACKAGE_NAME,
      url: resolveWixBillableItemsV1BillableItemsUrl({
        protoPath: "/v1/bulk/billable-items/update-tags-by-filter",
        data: payload,
        host
      }),
      data: payload
    };
    return metadata;
  }
  return __bulkUpdateBillableItemTagsByFilter;
}
function searchBillableItems(payload) {
  function __searchBillableItems({ host }) {
    const serializedData = transformPaths(payload, [
      {
        transformFn: transformSDKFloatToRESTFloat,
        paths: [
          { path: "search.aggregations.range.buckets.from" },
          { path: "search.aggregations.range.buckets.to" },
          {
            path: "search.aggregations.nested.nestedAggregations.range.buckets.from"
          },
          {
            path: "search.aggregations.nested.nestedAggregations.range.buckets.to"
          }
        ]
      }
    ]);
    const metadata = {
      entityFqdn: "wix.billable_items.v1.billable_item",
      method: "POST",
      methodFqn: "wix.billable_items.v1.BillableItems.SearchBillableItems",
      packageName: PACKAGE_NAME,
      url: resolveWixBillableItemsV1BillableItemsUrl({
        protoPath: "/v1/billable-items/search",
        data: serializedData,
        host
      }),
      data: serializedData,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "billableItems.createdDate" },
            { path: "billableItems.updatedDate" }
          ]
        },
        {
          transformFn: transformRESTFloatToSDKFloat,
          paths: [
            { path: "aggregationData.results.ranges.results.from" },
            { path: "aggregationData.results.ranges.results.to" },
            {
              path: "aggregationData.results.groupedByValue.results.nestedResults.ranges.results.from"
            },
            {
              path: "aggregationData.results.groupedByValue.results.nestedResults.ranges.results.to"
            },
            {
              path: "aggregationData.results.nested.results.results.*.range.from"
            },
            {
              path: "aggregationData.results.nested.results.results.*.range.to"
            },
            { path: "aggregationData.results.scalar.value" },
            {
              path: "aggregationData.results.groupedByValue.results.nestedResults.scalar.value"
            },
            {
              path: "aggregationData.results.nested.results.results.*.scalar.value"
            }
          ]
        }
      ])
    };
    return metadata;
  }
  return __searchBillableItems;
}

// src/billable-items-v1-billable-item-billable-items.universal.ts
import { transformSDKImageToRESTImage } from "@wix/sdk-runtime/transformations/image";
import { transformRESTImageToSDKImage } from "@wix/sdk-runtime/transformations/image";
import { transformPaths as transformPaths2 } from "@wix/sdk-runtime/transformations/transform-paths";
var WebhookIdentityType = /* @__PURE__ */ ((WebhookIdentityType2) => {
  WebhookIdentityType2["UNKNOWN"] = "UNKNOWN";
  WebhookIdentityType2["ANONYMOUS_VISITOR"] = "ANONYMOUS_VISITOR";
  WebhookIdentityType2["MEMBER"] = "MEMBER";
  WebhookIdentityType2["WIX_USER"] = "WIX_USER";
  WebhookIdentityType2["APP"] = "APP";
  return WebhookIdentityType2;
})(WebhookIdentityType || {});
var SortOrder = /* @__PURE__ */ ((SortOrder2) => {
  SortOrder2["ASC"] = "ASC";
  SortOrder2["DESC"] = "DESC";
  return SortOrder2;
})(SortOrder || {});
var SortType = /* @__PURE__ */ ((SortType2) => {
  SortType2["COUNT"] = "COUNT";
  SortType2["VALUE"] = "VALUE";
  return SortType2;
})(SortType || {});
var SortDirection = /* @__PURE__ */ ((SortDirection2) => {
  SortDirection2["DESC"] = "DESC";
  SortDirection2["ASC"] = "ASC";
  return SortDirection2;
})(SortDirection || {});
var MissingValues = /* @__PURE__ */ ((MissingValues2) => {
  MissingValues2["EXCLUDE"] = "EXCLUDE";
  MissingValues2["INCLUDE"] = "INCLUDE";
  return MissingValues2;
})(MissingValues || {});
var ScalarType = /* @__PURE__ */ ((ScalarType2) => {
  ScalarType2["UNKNOWN_SCALAR_TYPE"] = "UNKNOWN_SCALAR_TYPE";
  ScalarType2["COUNT_DISTINCT"] = "COUNT_DISTINCT";
  ScalarType2["MIN"] = "MIN";
  ScalarType2["MAX"] = "MAX";
  return ScalarType2;
})(ScalarType || {});
var NestedAggregationType = /* @__PURE__ */ ((NestedAggregationType2) => {
  NestedAggregationType2["UNKNOWN_AGGREGATION_TYPE"] = "UNKNOWN_AGGREGATION_TYPE";
  NestedAggregationType2["VALUE"] = "VALUE";
  NestedAggregationType2["RANGE"] = "RANGE";
  NestedAggregationType2["SCALAR"] = "SCALAR";
  NestedAggregationType2["DATE_HISTOGRAM"] = "DATE_HISTOGRAM";
  return NestedAggregationType2;
})(NestedAggregationType || {});
var Interval = /* @__PURE__ */ ((Interval2) => {
  Interval2["UNKNOWN_INTERVAL"] = "UNKNOWN_INTERVAL";
  Interval2["YEAR"] = "YEAR";
  Interval2["MONTH"] = "MONTH";
  Interval2["WEEK"] = "WEEK";
  Interval2["DAY"] = "DAY";
  Interval2["HOUR"] = "HOUR";
  Interval2["MINUTE"] = "MINUTE";
  Interval2["SECOND"] = "SECOND";
  return Interval2;
})(Interval || {});
var AggregationType = /* @__PURE__ */ ((AggregationType2) => {
  AggregationType2["UNKNOWN_AGGREGATION_TYPE"] = "UNKNOWN_AGGREGATION_TYPE";
  AggregationType2["VALUE"] = "VALUE";
  AggregationType2["RANGE"] = "RANGE";
  AggregationType2["SCALAR"] = "SCALAR";
  AggregationType2["DATE_HISTOGRAM"] = "DATE_HISTOGRAM";
  AggregationType2["NESTED"] = "NESTED";
  return AggregationType2;
})(AggregationType || {});
var Mode = /* @__PURE__ */ ((Mode2) => {
  Mode2["OR"] = "OR";
  Mode2["AND"] = "AND";
  return Mode2;
})(Mode || {});
async function createBillableItem2(billableItem) {
  const { httpClient, sideEffects } = arguments[1];
  const payload = transformPaths2(
    renameKeysFromSDKRequestToRESTRequest({ billableItem }),
    [
      {
        transformFn: transformSDKImageToRESTImage,
        paths: [{ path: "billableItem.image" }]
      }
    ]
  );
  const reqOpts = createBillableItem(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(
      transformPaths2(result.data, [
        {
          transformFn: transformRESTImageToSDKImage,
          paths: [{ path: "billableItem.image" }]
        }
      ])
    )?.billableItem;
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: { billableItem: "$[0]" },
        singleArgumentUnchanged: false
      },
      ["billableItem"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function getBillableItem2(billableItemId) {
  const { httpClient, sideEffects } = arguments[1];
  const payload = renameKeysFromSDKRequestToRESTRequest({
    billableItemId
  });
  const reqOpts = getBillableItem(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(
      transformPaths2(result.data, [
        {
          transformFn: transformRESTImageToSDKImage,
          paths: [{ path: "billableItem.image" }]
        }
      ])
    )?.billableItem;
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: { billableItemId: "$[0]" },
        singleArgumentUnchanged: false
      },
      ["billableItemId"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function updateBillableItem2(_id, billableItem) {
  const { httpClient, sideEffects } = arguments[2];
  const payload = transformPaths2(
    renameKeysFromSDKRequestToRESTRequest({
      billableItem: { ...billableItem, id: _id }
    }),
    [
      {
        transformFn: transformSDKImageToRESTImage,
        paths: [{ path: "billableItem.image" }]
      }
    ]
  );
  const reqOpts = updateBillableItem(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(
      transformPaths2(result.data, [
        {
          transformFn: transformRESTImageToSDKImage,
          paths: [{ path: "billableItem.image" }]
        }
      ])
    )?.billableItem;
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: { billableItem: "$[1]" },
        explicitPathsToArguments: { "billableItem.id": "$[0]" },
        singleArgumentUnchanged: false
      },
      ["_id", "billableItem"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function deleteBillableItem2(billableItemId) {
  const { httpClient, sideEffects } = arguments[1];
  const payload = renameKeysFromSDKRequestToRESTRequest({
    billableItemId
  });
  const reqOpts = deleteBillableItem(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: { billableItemId: "$[0]" },
        singleArgumentUnchanged: false
      },
      ["billableItemId"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
function queryBillableItems2() {
  const { httpClient, sideEffects } = arguments[0];
  return queryBuilder({
    func: async (payload) => {
      const reqOpts = queryBillableItems(payload);
      sideEffects?.onSiteCall?.();
      try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return result;
      } catch (err) {
        sideEffects?.onError?.(err);
        throw err;
      }
    },
    requestTransformer: (query) => {
      const args = [query, {}];
      return renameKeysFromSDKRequestToRESTRequest({
        ...args?.[1],
        query: args?.[0]
      });
    },
    responseTransformer: ({
      data
    }) => {
      const transformedData = renameKeysFromRESTResponseToSDKResponse(
        transformPaths2(data, [
          {
            transformFn: transformRESTImageToSDKImage,
            paths: [{ path: "billableItems.image" }]
          }
        ])
      );
      return {
        items: transformedData?.billableItems,
        pagingMetadata: transformedData?.pagingMetadata
      };
    },
    errorTransformer: (err) => {
      const transformedError = sdkTransformError(err, {
        spreadPathsToArguments: {},
        explicitPathsToArguments: { query: "$[0]" },
        singleArgumentUnchanged: false
      });
      throw transformedError;
    },
    pagingMethod: "CURSOR",
    transformationPaths: {}
  });
}
async function bulkCreateBillableItems2(billableItems, options) {
  const { httpClient, sideEffects } = arguments[2];
  const payload = transformPaths2(
    renameKeysFromSDKRequestToRESTRequest({
      billableItems,
      returnEntity: options?.returnEntity
    }),
    [
      {
        transformFn: transformSDKImageToRESTImage,
        paths: [{ path: "billableItems.image" }]
      }
    ]
  );
  const reqOpts = bulkCreateBillableItems(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(
      transformPaths2(result.data, [
        {
          transformFn: transformRESTImageToSDKImage,
          paths: [{ path: "results.item.image" }]
        }
      ])
    );
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: {
          billableItems: "$[0]",
          returnEntity: "$[1].returnEntity"
        },
        singleArgumentUnchanged: false
      },
      ["billableItems", "options"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function bulkUpdateBillableItems2(billableItems, options) {
  const { httpClient, sideEffects } = arguments[2];
  const payload = transformPaths2(
    renameKeysFromSDKRequestToRESTRequest({
      billableItems,
      returnEntity: options?.returnEntity
    }),
    [
      {
        transformFn: transformSDKImageToRESTImage,
        paths: [{ path: "billableItems.billableItem.image" }]
      }
    ]
  );
  const reqOpts = bulkUpdateBillableItems(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(
      transformPaths2(result.data, [
        {
          transformFn: transformRESTImageToSDKImage,
          paths: [{ path: "results.item.image" }]
        }
      ])
    );
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: {
          billableItems: "$[0]",
          returnEntity: "$[1].returnEntity"
        },
        singleArgumentUnchanged: false
      },
      ["billableItems", "options"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function bulkDeleteBillableItems2(billableItemIds) {
  const { httpClient, sideEffects } = arguments[1];
  const payload = renameKeysFromSDKRequestToRESTRequest({
    billableItemIds
  });
  const reqOpts = bulkDeleteBillableItems(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(result.data);
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: { billableItemIds: "$[0]" },
        singleArgumentUnchanged: false
      },
      ["billableItemIds"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function bulkUpdateBillableItemTags2(billableItemIds, options) {
  const { httpClient, sideEffects } = arguments[2];
  const payload = renameKeysFromSDKRequestToRESTRequest({
    billableItemIds,
    assignTags: options?.assignTags,
    unassignTags: options?.unassignTags
  });
  const reqOpts = bulkUpdateBillableItemTags(
    payload
  );
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(result.data);
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: {
          billableItemIds: "$[0]",
          assignTags: "$[1].assignTags",
          unassignTags: "$[1].unassignTags"
        },
        singleArgumentUnchanged: false
      },
      ["billableItemIds", "options"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function bulkUpdateBillableItemTagsByFilter2(filter, options) {
  const { httpClient, sideEffects } = arguments[2];
  const payload = renameKeysFromSDKRequestToRESTRequest({
    filter,
    assignTags: options?.assignTags,
    unassignTags: options?.unassignTags
  });
  const reqOpts = bulkUpdateBillableItemTagsByFilter(
    payload
  );
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(result.data);
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: {
          filter: "$[0]",
          assignTags: "$[1].assignTags",
          unassignTags: "$[1].unassignTags"
        },
        singleArgumentUnchanged: false
      },
      ["filter", "options"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function searchBillableItems2(search) {
  const { httpClient, sideEffects } = arguments[1];
  const payload = renameKeysFromSDKRequestToRESTRequest({ search });
  const reqOpts = searchBillableItems(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(
      transformPaths2(result.data, [
        {
          transformFn: transformRESTImageToSDKImage,
          paths: [{ path: "billableItems.image" }]
        }
      ])
    );
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: { search: "$[0]" },
        singleArgumentUnchanged: false
      },
      ["search"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
export {
  AggregationType,
  Interval,
  MissingValues,
  Mode,
  NestedAggregationType,
  ScalarType,
  SortDirection,
  SortOrder,
  SortType,
  WebhookIdentityType,
  bulkCreateBillableItems2 as bulkCreateBillableItems,
  bulkDeleteBillableItems2 as bulkDeleteBillableItems,
  bulkUpdateBillableItemTags2 as bulkUpdateBillableItemTags,
  bulkUpdateBillableItemTagsByFilter2 as bulkUpdateBillableItemTagsByFilter,
  bulkUpdateBillableItems2 as bulkUpdateBillableItems,
  createBillableItem2 as createBillableItem,
  deleteBillableItem2 as deleteBillableItem,
  getBillableItem2 as getBillableItem,
  queryBillableItems2 as queryBillableItems,
  searchBillableItems2 as searchBillableItems,
  updateBillableItem2 as updateBillableItem
};
//# sourceMappingURL=index.typings.mjs.map