import { HttpClient, NonNullablePaths, EventDefinition, MaybeContext, BuildRESTFunction, BuildEventDefinition } from '@wix/sdk-types';
import { B as BillableItem, C as CreateBillableItemApplicationErrors, U as UpdateBillableItem, a as BillableItemsQueryBuilder, b as BulkCreateBillableItemsOptions, c as BulkCreateBillableItemsResponse, M as MaskedBillableItem, d as BulkUpdateBillableItemsOptions, e as BulkUpdateBillableItemsResponse, f as BulkDeleteBillableItemsResponse, g as BulkUpdateBillableItemTagsOptions, V as V1BulkUpdateBillableItemTagsResponse, h as BulkUpdateBillableItemTagsApplicationErrors, i as BulkUpdateBillableItemTagsByFilterOptions, j as V1BulkUpdateBillableItemTagsByFilterResponse, k as BulkUpdateBillableItemTagsByFilterApplicationErrors, l as BillableItemSearch, S as SearchBillableItemsResponse, m as BillableItemCreatedEnvelope, n as BillableItemDeletedEnvelope, o as BillableItemUpdatedEnvelope } from './billable-items-v1-billable-item-billable-items.universal-RzrzC-9-.js';
export { Q as ActionEvent, av as Aggregation, aJ as AggregationData, aw as AggregationKindOneOf, b0 as AggregationResults, b1 as AggregationResultsResultOneOf, aQ as AggregationResultsScalarResult, A as AggregationType, z as ApplicationError, b2 as BaseEventMetadata, b5 as BillableItemSearchSpec, b4 as BillableItemsQueryResult, F as BulkActionMetadata, ak as BulkBillableItemResult, aj as BulkCreateBillableItemsRequest, an as BulkDeleteBillableItemsRequest, ao as BulkDeleteBillableItemsResponseBulkBillableItemResult, G as BulkUpdateBillableItemTagsByFilterRequest, H as BulkUpdateBillableItemTagsByFilterResponse, w as BulkUpdateBillableItemTagsRequest, x as BulkUpdateBillableItemTagsResponse, aq as BulkUpdateBillableItemTagsResponseBulkUpdateBillableItemTagsResult, D as BulkUpdateBillableItemTagsResult, al as BulkUpdateBillableItemsRequest, am as BulkUpdateBillableItemsResponseBulkBillableItemResult, _ as CreateBillableItemRequest, $ as CreateBillableItemResponse, aa as CursorPaging, ac as CursorPagingMetadata, a7 as CursorQuery, a8 as CursorQueryPagingMethodOneOf, at as CursorSearch, au as CursorSearchPagingMethodOneOf, ad as Cursors, aD as DateHistogramAggregation, aY as DateHistogramResult, a_ as DateHistogramResults, a4 as DeleteBillableItemRequest, a5 as DeleteBillableItemResponse, J as DomainEvent, K as DomainEventBodyOneOf, L as EntityCreatedEvent, P as EntityDeletedEvent, O as EntityUpdatedEvent, b3 as EventMetadata, E as ExtendedFields, a0 as GetBillableItemRequest, a1 as GetBillableItemResponse, aZ as GroupByValueResults, Y as IdentificationData, Z as IdentificationDataIdOneOf, ay as IncludeMissingValuesOptions, ah as InternalCursorPaging, af as InternalCursorQuery, ag as InternalCursorQueryPagingMethodOneOf, ae as InternalQueryBillableItemsRequest, ai as InternalQueryBillableItemsResponse, I as Interval, y as ItemMetadata, X as MessageEnvelope, s as MissingValues, u as Mode, aG as NestedAggregation, aE as NestedAggregationItem, aF as NestedAggregationItemKindOneOf, aM as NestedAggregationResults, aN as NestedAggregationResultsResultOneOf, N as NestedAggregationType, aV as NestedResultValue, aW as NestedResultValueResultOneOf, a$ as NestedResults, aR as NestedValueAggregationResult, aI as PagingMetadataV2, a6 as QueryBillableItemsRequest, ab as QueryBillableItemsResponse, aB as RangeAggregation, aL as RangeAggregationResult, ax as RangeBucket, aT as RangeResult, aP as RangeResults, R as RestoreInfo, aX as Results, aC as ScalarAggregation, aU as ScalarResult, t as ScalarType, as as SearchBillableItemsRequest, aH as SearchDetails, r as SortDirection, p as SortOrder, q as SortType, a9 as Sorting, v as TagList, T as Tags, a2 as UpdateBillableItemRequest, a3 as UpdateBillableItemResponse, ar as V1BulkUpdateBillableItemTagsByFilterRequest, ap as V1BulkUpdateBillableItemTagsRequest, az as ValueAggregation, aA as ValueAggregationOptionsOneOf, aK as ValueAggregationResult, aS as ValueResult, aO as ValueResults, W as WebhookIdentityType } from './billable-items-v1-billable-item-billable-items.universal-RzrzC-9-.js';

type BillableItemNonNullablePaths = `name` | `price` | `tags.privateTags.tagIds`;
declare function createBillableItem$1(httpClient: HttpClient): CreateBillableItemSignature;
interface CreateBillableItemSignature {
    /**
     * Creates a billable item.
     * @param - Billable item to create.
     * @returns Created billable item.
     */
    (billableItem: NonNullablePaths<BillableItem, `name` | `price`>): Promise<NonNullablePaths<BillableItem, BillableItemNonNullablePaths> & {
        __applicationErrorsType?: CreateBillableItemApplicationErrors;
    }>;
}
declare function getBillableItem$1(httpClient: HttpClient): GetBillableItemSignature;
interface GetBillableItemSignature {
    /**
     * Retrieves a billable item.
     * @param - Billable item ID.
     * @returns Requested billable item.
     */
    (billableItemId: string): Promise<NonNullablePaths<BillableItem, BillableItemNonNullablePaths>>;
}
declare function updateBillableItem$1(httpClient: HttpClient): UpdateBillableItemSignature;
interface UpdateBillableItemSignature {
    /**
     * Updates a billable item.
     *
     *
     * Each time the BillableItem is updated,
     * `revision` increments by 1.
     * The current `revision` must be passed when updating the billable item.
     * This ensures you're working with the latest billable item
     * and prevents unintended overwrites.
     * @param - Billable item ID.
     * @returns Updated billable item.
     */
    (_id: string, billableItem: NonNullablePaths<UpdateBillableItem, `name` | `price` | `revision`>): Promise<NonNullablePaths<BillableItem, BillableItemNonNullablePaths>>;
}
declare function deleteBillableItem$1(httpClient: HttpClient): DeleteBillableItemSignature;
interface DeleteBillableItemSignature {
    /**
     * Permanently deletes a billable item.
     * @param - Billable item ID to delete.
     */
    (billableItemId: string): Promise<void>;
}
declare function queryBillableItems$1(httpClient: HttpClient): QueryBillableItemsSignature;
interface QueryBillableItemsSignature {
    /**
     * Retrieves a list of BillableItems, given the provided [paging, filtering, and sorting](https://dev.wix.com/api/rest/getting-started/sorting-and-paging).
     *
     * Up to 1,000 BillableItems can be returned per request.
     *
     * To learn how to query BillableItems, see [API Query Language](https://dev.wix.com/api/rest/getting-started/api-query-language).
     */
    (): BillableItemsQueryBuilder;
}
declare function bulkCreateBillableItems$1(httpClient: HttpClient): BulkCreateBillableItemsSignature;
interface BulkCreateBillableItemsSignature {
    /**
     * Create multiple billable items.
     * @param - List of billable items to create.
     * @param - Field options.
     */
    (billableItems: BillableItem[], options?: BulkCreateBillableItemsOptions): Promise<NonNullablePaths<BulkCreateBillableItemsResponse, `results` | `results.${number}.itemMetadata.originalIndex` | `results.${number}.itemMetadata.success` | `results.${number}.itemMetadata.error.code` | `results.${number}.itemMetadata.error.description` | {
        [P in BillableItemNonNullablePaths]: `results.${number}.item.${P}`;
    }[BillableItemNonNullablePaths] | `bulkActionMetadata.totalSuccesses` | `bulkActionMetadata.totalFailures` | `bulkActionMetadata.undetailedFailures`>>;
}
declare function bulkUpdateBillableItems$1(httpClient: HttpClient): BulkUpdateBillableItemsSignature;
interface BulkUpdateBillableItemsSignature {
    /**
     * Updates multiple billable items.
     * @param - Billable items to update.
     * @param - Field options.
     */
    (billableItems: NonNullablePaths<MaskedBillableItem, `billableItem` | `billableItem._id` | `billableItem.revision`>[], options?: BulkUpdateBillableItemsOptions): Promise<NonNullablePaths<BulkUpdateBillableItemsResponse, `results` | `results.${number}.itemMetadata.originalIndex` | `results.${number}.itemMetadata.success` | `results.${number}.itemMetadata.error.code` | `results.${number}.itemMetadata.error.description` | {
        [P in BillableItemNonNullablePaths]: `results.${number}.item.${P}`;
    }[BillableItemNonNullablePaths] | `bulkActionMetadata.totalSuccesses` | `bulkActionMetadata.totalFailures` | `bulkActionMetadata.undetailedFailures`>>;
}
declare function bulkDeleteBillableItems$1(httpClient: HttpClient): BulkDeleteBillableItemsSignature;
interface BulkDeleteBillableItemsSignature {
    /**
     * Delete multiple billable items.
     * @param - Billable item IDs to delete.
     */
    (billableItemIds: string[]): Promise<NonNullablePaths<BulkDeleteBillableItemsResponse, `results` | `results.${number}.itemMetadata.originalIndex` | `results.${number}.itemMetadata.success` | `results.${number}.itemMetadata.error.code` | `results.${number}.itemMetadata.error.description` | `bulkActionMetadata.totalSuccesses` | `bulkActionMetadata.totalFailures` | `bulkActionMetadata.undetailedFailures`>>;
}
declare function bulkUpdateBillableItemTags$1(httpClient: HttpClient): BulkUpdateBillableItemTagsSignature;
interface BulkUpdateBillableItemTagsSignature {
    /**
     * Updates tags for multiple billable items.
     * A tag that appears both in the list of assign and unassign tags, will be assigned.
     * @param - IDs of billable items which tags will be updated.
     * @param - Field options.
     */
    (billableItemIds: string[], options?: BulkUpdateBillableItemTagsOptions): Promise<NonNullablePaths<V1BulkUpdateBillableItemTagsResponse, `results` | `results.${number}.itemMetadata.originalIndex` | `results.${number}.itemMetadata.success` | `results.${number}.itemMetadata.error.code` | `results.${number}.itemMetadata.error.description` | `bulkActionMetadata.totalSuccesses` | `bulkActionMetadata.totalFailures` | `bulkActionMetadata.undetailedFailures`> & {
        __applicationErrorsType?: BulkUpdateBillableItemTagsApplicationErrors;
    }>;
}
declare function bulkUpdateBillableItemTagsByFilter$1(httpClient: HttpClient): BulkUpdateBillableItemTagsByFilterSignature;
interface BulkUpdateBillableItemTagsByFilterSignature {
    /**
     * Updates tags on multiple billable items by filter. Works asynchronously, and returns a job ID.
     *
     * An empty filter will update all billable items.
     *
     * A tag that is specified both in the list of assign and unassign tags, will be assigned.
     *
     * Specify the returned jobId in Get Async Job ([SDK](https://dev.wix.com/docs/sdk/backend-modules/async-jobs/get-async-job) | [REST](https://dev.wix.com/docs/rest/business-management/async-job/get-async-job)) to track the job's status.
     * @param - Filter to select relevant billable items.
     * @param - Field options.
     */
    (filter: Record<string, any>, options?: BulkUpdateBillableItemTagsByFilterOptions): Promise<NonNullablePaths<V1BulkUpdateBillableItemTagsByFilterResponse, `jobId`> & {
        __applicationErrorsType?: BulkUpdateBillableItemTagsByFilterApplicationErrors;
    }>;
}
declare function searchBillableItems$1(httpClient: HttpClient): SearchBillableItemsSignature;
interface SearchBillableItemsSignature {
    /**
     * Retrieves a list of up to 100 billable items, given the specified filtering, search expression, sorting, and cursor paging ([SDK](https://dev.wix.com/docs/sdk/articles/work-with-the-sdk/api-query-language) | [REST](https://dev.wix.com/api/rest/getting-started/api-query-language)).
     * @param - Search options.
     */
    (search: BillableItemSearch): Promise<NonNullablePaths<SearchBillableItemsResponse, {
        [P in BillableItemNonNullablePaths]: `billableItems.${number}.${P}`;
    }[BillableItemNonNullablePaths] | `aggregationData.results` | `aggregationData.results.${number}.scalar.type` | `aggregationData.results.${number}.scalar.value` | `aggregationData.results.${number}.name` | `aggregationData.results.${number}.type` | `aggregationData.results.${number}.fieldPath`>>;
}
declare const onBillableItemCreated$1: EventDefinition<BillableItemCreatedEnvelope, "wix.billable_items.v1.billable_item_created">;
declare const onBillableItemDeleted$1: EventDefinition<BillableItemDeletedEnvelope, "wix.billable_items.v1.billable_item_deleted">;
declare const onBillableItemUpdated$1: EventDefinition<BillableItemUpdatedEnvelope, "wix.billable_items.v1.billable_item_updated">;

declare const createBillableItem: MaybeContext<BuildRESTFunction<typeof createBillableItem$1> & typeof createBillableItem$1>;
declare const getBillableItem: MaybeContext<BuildRESTFunction<typeof getBillableItem$1> & typeof getBillableItem$1>;
declare const updateBillableItem: MaybeContext<BuildRESTFunction<typeof updateBillableItem$1> & typeof updateBillableItem$1>;
declare const deleteBillableItem: MaybeContext<BuildRESTFunction<typeof deleteBillableItem$1> & typeof deleteBillableItem$1>;
declare const queryBillableItems: MaybeContext<BuildRESTFunction<typeof queryBillableItems$1> & typeof queryBillableItems$1>;
declare const bulkCreateBillableItems: MaybeContext<BuildRESTFunction<typeof bulkCreateBillableItems$1> & typeof bulkCreateBillableItems$1>;
declare const bulkUpdateBillableItems: MaybeContext<BuildRESTFunction<typeof bulkUpdateBillableItems$1> & typeof bulkUpdateBillableItems$1>;
declare const bulkDeleteBillableItems: MaybeContext<BuildRESTFunction<typeof bulkDeleteBillableItems$1> & typeof bulkDeleteBillableItems$1>;
declare const bulkUpdateBillableItemTags: MaybeContext<BuildRESTFunction<typeof bulkUpdateBillableItemTags$1> & typeof bulkUpdateBillableItemTags$1>;
declare const bulkUpdateBillableItemTagsByFilter: MaybeContext<BuildRESTFunction<typeof bulkUpdateBillableItemTagsByFilter$1> & typeof bulkUpdateBillableItemTagsByFilter$1>;
declare const searchBillableItems: MaybeContext<BuildRESTFunction<typeof searchBillableItems$1> & typeof searchBillableItems$1>;
/**
 * Triggered when a billable item is created.
 */
declare const onBillableItemCreated: BuildEventDefinition<typeof onBillableItemCreated$1>;
/**
 * Triggered when a billable item is deleted.
 */
declare const onBillableItemDeleted: BuildEventDefinition<typeof onBillableItemDeleted$1>;
/**
 * Triggered when a billable item is updated.
 */
declare const onBillableItemUpdated: BuildEventDefinition<typeof onBillableItemUpdated$1>;

export { BillableItem, BillableItemCreatedEnvelope, BillableItemDeletedEnvelope, BillableItemUpdatedEnvelope, BillableItemsQueryBuilder, BulkCreateBillableItemsOptions, BulkCreateBillableItemsResponse, BulkDeleteBillableItemsResponse, BulkUpdateBillableItemTagsByFilterOptions, BulkUpdateBillableItemTagsOptions, BulkUpdateBillableItemsOptions, BulkUpdateBillableItemsResponse, MaskedBillableItem, SearchBillableItemsResponse, UpdateBillableItem, V1BulkUpdateBillableItemTagsByFilterResponse, V1BulkUpdateBillableItemTagsResponse, bulkCreateBillableItems, bulkDeleteBillableItems, bulkUpdateBillableItemTags, bulkUpdateBillableItemTagsByFilter, bulkUpdateBillableItems, createBillableItem, deleteBillableItem, getBillableItem, onBillableItemCreated, onBillableItemDeleted, onBillableItemUpdated, queryBillableItems, searchBillableItems, updateBillableItem };
